==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/sound/translations/sound_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>@default</name>
    <message>
        <source>Sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound paths</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Test sound playing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play a sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable sound notifications</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SoundBuddyConfigurationWidget</name>
    <message>
        <source>Use custom sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SoundChatConfigurationWidget</name>
    <message>
        <source>Sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use custom sound</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SoundConfigurationUiHandler</name>
    <message>
        <source>Custom</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SoundMuteAction</name>
    <message>
        <source>Play Sounds</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/sound/translations/sound_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Sound</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notifications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sound theme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sound paths</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Test sound playing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Play a sound</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable sound notifications</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SoundBuddyConfigurationWidget</name>
    <message>
        <source>Use custom sound</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SoundChatConfigurationWidget</name>
    <message>
        <source>Sound</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use custom sound</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SoundConfigurationUiHandler</name>
    <message>
        <source>Custom</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SoundMuteAction</name>
    <message>
        <source>Play Sounds</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
